@@ -1,10 +1,10 @@
 package MooseX::MethodAttributes::Role::Meta::Class;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # ABSTRACT: metaclass role for storing code attributes
 
 use Moose::Role;
-use Moose::Util qw/find_meta/;
+use Moose::Util qw/find_meta does_role/;
 use MooseX::Types::Moose qw/HashRef ArrayRef Str Int/;
 
 use namespace::clean -except => 'meta';
@@ -55,9 +55,11 @@ sub get_method_with_attributes_list {
     } map {
         my $addr = 0 + $_->_get_attributed_coderef;
         exists $self->_method_attribute_map->{$addr}
-            ? [$addr, $_]
-            : ()
-    } grep { $_->can('_get_attributed_coderef') } @methods;
+        ? [$addr, $_]
+        : ()
+    } grep { 
+        $_->can('_get_attributed_coderef')
+    } @methods;
 }
 
 
@@ -73,19 +75,52 @@ sub get_all_methods_with_attributes {
         ($meta && ($meth = $meta->can('get_method_with_attributes_list')))
             ? $meta->$meth
             : ()
-    } reverse $self->linearized_isa
+    } reverse $self->linearized_isa;
 }
 
 
 sub get_nearest_methods_with_attributes {
     my ($self) = @_;
-    
-    map {
+    my @list = map {
         my $m = $self->find_method_by_name($_->name);
         my $meth = $m->can('attributes');
         my $attrs = $meth ? $m->$meth() : [];
         scalar @{ $attrs } ? ( $m ) : ( );
     } $self->get_all_methods_with_attributes;
+    return @list;
+}
+
+foreach my $type (qw/after before around/) {
+    around "add_${type}_method_modifier" => sub {
+        my $orig = shift;
+        my $meta = shift;
+        my ($method_name) = @_;
+    
+        unless(
+            does_role($meta, 'MooseX::MethodAttributes::Role::Meta::Class')
+            && does_role($meta->method_metaclass, 'MooseX::MethodAttributes::Role::Meta::Method')
+            && does_role($meta->wrapped_method_metaclass, 'MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped')
+        ) {
+    
+            Moose::Util::MetaRole::apply_metaclass_roles(
+                for_class                      => $meta->name,
+                metaclass_roles                => ['MooseX::MethodAttributes::Role::Meta::Class'],
+                method_metaclass_roles         => ['MooseX::MethodAttributes::Role::Meta::Method'],
+                wrapped_method_metaclass_roles => ['MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped'],
+            );
+            # Get replaced metaclass..
+            $meta = find_meta($meta->name);
+        }
+        my $code = $meta->$orig(@_);
+        my $method = $meta->get_method($method_name);
+        if (
+            does_role($method->get_original_method, 'MooseX::MethodAttributes::Role::Meta::Method')
+            || does_role($method->get_original_method, 'MooseX::MethodAttributes::Role::Meta::Method::Wrapped')
+        ) {
+            MooseX::MethodAttributes::Role::Meta::Method::Wrapped->meta->apply($method);
+        }
+        return $code;
+    }
 }
 
 1;
@@ -98,7 +133,7 @@ MooseX::MethodAttributes::Role::Meta::Class - metaclass role for storing code at
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 METHODS
 
